! ----------------------------------------------------------------- FltPrjct
      Program FltPrjct

! Computes the lat and long for the surface projections of the
! four corners of a rectangular fault whose orientation is specified
! by the lat, long of a reference point, the depth to that reference point,
! the fault strike and dip, and the distances along strike from
! the reference point to the two ends of the fault, and the along-dip distances
! from the reference point to the top and bottom edges of the fault

! The input is contained in a control file; here is an example;
!Control file for program fltprjct.for
!Name of output file:
!  fltprjct.out
!Fault info (fault name/ref lat, long, depth, strike, dip, s1, s2, w1, w2):
! Lavic Lake Fault (middle branch)
!  34.466, -116.239, 0.275, 346.0, 85.0, 0.0, 33.0, 0.0, 16.2
! Lavic Lake Fault (west branch)
!  34.571 -116.271 0.261 322.0 75.0 0.0 21.0 0.0 15.4
! Bullion Fault
!  34.311 -116.108 0.269 325.0 85.0 0.0 30.0 0.0 16.2
! StoP


! Dates: 11/30/00 - Written by D.M. Boore
!        11/12/01 - Renamed from flt2deg (easier for me to find in the future)
!        11/14/01 - Suggest default control file name
!        05/06/02 - Increase precision of output
!        06/18/09 - Slight correction in output format
!        11/18/15 - Some modernization of code
!        12/15/16 - Allow for longer output file name

      character buf*80, f_col*300, fault_info(5)*80

      real s(2), w(2), vlat(4), vlong(4), u_ss(2,2), u_ds(2,2)
      integer iorder(5)

!      double precision vn, ve, alat_ref, along_ref, vlat, vlong

      character f_ctl*300
      logical f_ctl_exist

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr = FLTPRJCT.CTL;'//
     :    ' CTL-BRK to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl == ' ') f_ctl='fltprjct.ctl'
        call trim_c(f_ctl, nc_f_ctl)
        inquire(file=f_ctl(1:nc_f_ctl), exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_ctl(1:nc_f_ctl),status='unknown')
      write(*, '(1x,a)') f_ctl(1:nc_f_ctl)

! Obtain info from control file:

      call skip(nu_ctl,2)

      f_col = ' '
      read(nu_ctl, '(a)') f_col
      call trim_c(f_col,nc_f_col)
      call get_lun(nu_col)
      open(nu_col, file=f_col(1:nc_f_col), status = 'unknown')
      
! Write header line:
      write(nu_col,'(1x,a, 6x,a, 6x,a, 1x,a)')
     :       'vertex', 'lat', 'long', 'fault_info'


      call skip(nu_ctl,1)

      loop_over_input: DO

      buf = ' '
      read(nu_ctl, '(a)') buf                   ! read title or stop
      write(*, '(1x,a)') buf
      call trim_c(buf,nc_buf)
      fault_info(1) = ' '
      fault_info(1) = buf
      call upstr(buf)
      if(buf(1:4) == 'STOP') then
        close(nu_ctl)
        close(nu_col)
        stop
      end if
      
      read(nu_ctl,*) alat_ref, along_ref, depth, strike, dip,
     :    s(1), s(2), w(1), w(2)        ! fault info

      do i = 2, 5
        fault_info(i) = ' '
      end do

      write(fault_info(2),'(a,1x,f7.3,1x,a,1x,f8.3)') 
     :   'ref_lat=', alat_ref, 'ref_long=', along_ref

      write(fault_info(3),'(a,1x,f6.3)') 
     :   'ref_depth=', depth

      write(fault_info(4),'(a,1x,f6.1,1x,a,1x,f5.1)') 
     :   'strike=', strike, 'dip=', dip

      write(fault_info(5),'(a,2(1x,f5.1),a,2(1x,f5.1))') 
     :   's1, s2=', s(1), s(2), '; w1, w2=', w(1), w(2)

! Construct ref to edge vectors:
      
      pi = 4.0 * atan(1.0)
      d2r = pi/180.0
      cdip = cos(d2r*dip)
      cstr = cos(d2r*strike)
      sstr = sin(d2r*strike)
      cstrp90 = cos(d2r*(strike+90.0))
      sstrp90 = sin(d2r*(strike+90.0))

      do j = 1, 2  ! which edge
        u_ss(1,j) = cstr * s(j)  ! north component 
        u_ss(2,j) = sstr * s(j)  ! east  component 
        u_ds(1,j) = cstrp90 * (cdip * w(j))  ! north component  
        u_ds(2,j) = sstrp90 * (cdip * w(j))  ! east  component 
      end do

! Construct vector from ref to each vertex:
      ivrt = 0
      do j = 1, 2 ! ss edge
        do i = 1, 2 ! ds edge
          ivrt = ivrt + 1
          vn = u_ss(1,j) + u_ds(1,i)
          ve = u_ss(2,j) + u_ds(2,i)
          vlat(ivrt) = alat_ref + vn/(6371.0 * d2r)
          vlong(ivrt) = along_ref + ve/(6371.0 * d2r * 
     :        cos(0.5 * (alat_ref + vlat(ivrt)) * d2r))
        end do
      end do

! Set up order of output:
      iorder(1) = 1   ! reorder output so can plot the surface projection
      iorder(2) = 3   ! of the rectangle
      iorder(3) = 4
      iorder(4) = 2
      iorder(5) = 1

      do i = 1, 5
        call trim_c(fault_info(i), nc_fault_info)
        write(nu_col, '(6x,i1, 1x,f8.4, 1x,f9.4, 1x,a)')
     :        i, vlat(iorder(i)), vlong(iorder(i)), 
     :        '"'//fault_info(i)(1:nc_fault_info)//'"'
      end do

      write(nu_col,*) ! write blank separator

      END DO loop_over_input

!      call km2deg_f( vn, ve, alat_ref, along_ref, 
!     :               vlat, vlong )

!      write(*,'(a,2(1x,f10.5))') ' vlat, vlong = ', vlat, vlong

!      write(nu_col,'(a,2(1x,f10.5))') ' Ref. lat, long. = ',
!     : alat_ref, along_ref

!      write(nu_col,'(a,2(1x,f10.5))') ' Distance north, east (km) = ',
!     : vn, ve

!      write(nu_col,'(a,2(1x,f10.5))') 
!     :  ' Using Richter tables: vlat, vlong = ', vlat, vlong

!      write(nu_col,'(a,2(1x,f10.5))') 
!     :  ' Using sphere approx : vlat, vlong = ', vlat, vlong

      end
! ----------------------------------------------------------------- FltPrjct

!      include '\forprogs\km2degss.for'
!      include '\forprogs\locate.for'
      include '\forprogs\upstr.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\skip.for'

